==> google-cloud-channel-1.7.1.tar.gz: google-cloud-channel-1.7.1/google/cloud/channel_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .channel_partner_links import (
    ChannelPartnerLink,
    ChannelPartnerLinkState,
    ChannelPartnerLinkView,
)
from .common import (
    AdminUser,
    CloudIdentityInfo,
    EduData,
    Value,
)
from .customers import (
    ContactInfo,
    Customer,
)
from .entitlements import (
    AssociationInfo,
    CommitmentSettings,
    Entitlement,
    Parameter,
    ProvisionedService,
    RenewalSettings,
    TransferableSku,
    TransferEligibility,
    TrialSettings,
)
from .offers import (
    Constraints,
    CustomerConstraints,
    Offer,
    ParameterDefinition,
    Period,
    Plan,
    Price,
    PriceByResource,
    PricePhase,
    PriceTier,
    PaymentPlan,
    PaymentType,
    PeriodType,
    PromotionalOrderType,
    ResourceType,
)
from .operations import OperationMetadata
from .products import (
    MarketingInfo,
    Media,
    Product,
    Sku,
    MediaType,
)
from .service import (
    ActivateEntitlementRequest,
    CancelEntitlementRequest,
    ChangeOfferRequest,
    ChangeParametersRequest,
    ChangeRenewalSettingsRequest,
    CheckCloudIdentityAccountsExistRequest,
    CheckCloudIdentityAccountsExistResponse,
    CloudIdentityCustomerAccount,
    CreateChannelPartnerLinkRequest,
    CreateCustomerRequest,
    CreateEntitlementRequest,
    DeleteCustomerRequest,
    GetChannelPartnerLinkRequest,
    GetCustomerRequest,
    GetEntitlementRequest,
    ImportCustomerRequest,
    ListChannelPartnerLinksRequest,
    ListChannelPartnerLinksResponse,
    ListCustomersRequest,
    ListCustomersResponse,
    ListEntitlementsRequest,
    ListEntitlementsResponse,
    ListOffersRequest,
    ListOffersResponse,
    ListProductsRequest,
    ListProductsResponse,
    ListPurchasableOffersRequest,
    ListPurchasableOffersResponse,
    ListPurchasableSkusRequest,
    ListPurchasableSkusResponse,
    ListSkusRequest,
    ListSkusResponse,
    ListSubscribersRequest,
    ListSubscribersResponse,
    ListTransferableOffersRequest,
    ListTransferableOffersResponse,
    ListTransferableSkusRequest,
    ListTransferableSkusResponse,
    LookupOfferRequest,
    ProvisionCloudIdentityRequest,
    PurchasableOffer,
    PurchasableSku,
    RegisterSubscriberRequest,
    RegisterSubscriberResponse,
    StartPaidServiceRequest,
    SuspendEntitlementRequest,
    TransferableOffer,
    TransferEntitlementsRequest,
    TransferEntitlementsResponse,
    TransferEntitlementsToGoogleRequest,
    UnregisterSubscriberRequest,
    UnregisterSubscriberResponse,
    UpdateChannelPartnerLinkRequest,
    UpdateCustomerRequest,
)
from .subscriber_event import (
    CustomerEvent,
    EntitlementEvent,
    SubscriberEvent,
)

__all__ = (
    "ChannelPartnerLink",
    "ChannelPartnerLinkState",
    "ChannelPartnerLinkView",
    "AdminUser",
    "CloudIdentityInfo",
    "EduData",
    "Value",
    "ContactInfo",
    "Customer",
    "AssociationInfo",
    "CommitmentSettings",
    "Entitlement",
    "Parameter",
    "ProvisionedService",
    "RenewalSettings",
    "TransferableSku",
    "TransferEligibility",
    "TrialSettings",
    "Constraints",
    "CustomerConstraints",
    "Offer",
    "ParameterDefinition",
    "Period",
    "Plan",
    "Price",
    "PriceByResource",
    "PricePhase",
    "PriceTier",
    "PaymentPlan",
    "PaymentType",
    "PeriodType",
    "PromotionalOrderType",
    "ResourceType",
    "OperationMetadata",
    "MarketingInfo",
    "Media",
    "Product",
    "Sku",
    "MediaType",
    "ActivateEntitlementRequest",
    "CancelEntitlementRequest",
    "ChangeOfferRequest",
    "ChangeParametersRequest",
    "ChangeRenewalSettingsRequest",
    "CheckCloudIdentityAccountsExistRequest",
    "CheckCloudIdentityAccountsExistResponse",
    "CloudIdentityCustomerAccount",
    "CreateChannelPartnerLinkRequest",
    "CreateCustomerRequest",
    "CreateEntitlementRequest",
    "DeleteCustomerRequest",
    "GetChannelPartnerLinkRequest",
    "GetCustomerRequest",
    "GetEntitlementRequest",
    "ImportCustomerRequest",
    "ListChannelPartnerLinksRequest",
    "ListChannelPartnerLinksResponse",
    "ListCustomersRequest",
    "ListCustomersResponse",
    "ListEntitlementsRequest",
    "ListEntitlementsResponse",
    "ListOffersRequest",
    "ListOffersResponse",
    "ListProductsRequest",
    "ListProductsResponse",
    "ListPurchasableOffersRequest",
    "ListPurchasableOffersResponse",
    "ListPurchasableSkusRequest",
    "ListPurchasableSkusResponse",
    "ListSkusRequest",
    "ListSkusResponse",
    "ListSubscribersRequest",
    "ListSubscribersResponse",
    "ListTransferableOffersRequest",
    "ListTransferableOffersResponse",
    "ListTransferableSkusRequest",
    "ListTransferableSkusResponse",
    "LookupOfferRequest",
    "ProvisionCloudIdentityRequest",
    "PurchasableOffer",
    "PurchasableSku",
    "RegisterSubscriberRequest",
    "RegisterSubscriberResponse",
    "StartPaidServiceRequest",
    "SuspendEntitlementRequest",
    "TransferableOffer",
    "TransferEntitlementsRequest",
    "TransferEntitlementsResponse",
    "TransferEntitlementsToGoogleRequest",
    "UnregisterSubscriberRequest",
    "UnregisterSubscriberResponse",
    "UpdateChannelPartnerLinkRequest",
    "UpdateCustomerRequest",
    "CustomerEvent",
    "EntitlementEvent",
    "SubscriberEvent",
)

==> google-cloud-channel-1.9.2.tar.gz: google-cloud-channel-1.9.2/google/cloud/channel_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .channel_partner_links import (
    ChannelPartnerLink,
    ChannelPartnerLinkState,
    ChannelPartnerLinkView,
)
from .common import AdminUser, CloudIdentityInfo, EduData, Value
from .customers import ContactInfo, Customer
from .entitlements import (
    AssociationInfo,
    CommitmentSettings,
    Entitlement,
    Parameter,
    ProvisionedService,
    RenewalSettings,
    TransferableSku,
    TransferEligibility,
    TrialSettings,
)
from .offers import (
    Constraints,
    CustomerConstraints,
    Offer,
    ParameterDefinition,
    PaymentPlan,
    PaymentType,
    Period,
    PeriodType,
    Plan,
    Price,
    PriceByResource,
    PricePhase,
    PriceTier,
    PromotionalOrderType,
    ResourceType,
)
from .operations import OperationMetadata
from .products import MarketingInfo, Media, MediaType, Product, Sku
from .repricing import (
    ChannelPartnerRepricingConfig,
    CustomerRepricingConfig,
    PercentageAdjustment,
    RebillingBasis,
    RepricingAdjustment,
    RepricingConfig,
)
from .service import (
    ActivateEntitlementRequest,
    CancelEntitlementRequest,
    ChangeOfferRequest,
    ChangeParametersRequest,
    ChangeRenewalSettingsRequest,
    CheckCloudIdentityAccountsExistRequest,
    CheckCloudIdentityAccountsExistResponse,
    CloudIdentityCustomerAccount,
    CreateChannelPartnerLinkRequest,
    CreateChannelPartnerRepricingConfigRequest,
    CreateCustomerRepricingConfigRequest,
    CreateCustomerRequest,
    CreateEntitlementRequest,
    DeleteChannelPartnerRepricingConfigRequest,
    DeleteCustomerRepricingConfigRequest,
    DeleteCustomerRequest,
    GetChannelPartnerLinkRequest,
    GetChannelPartnerRepricingConfigRequest,
    GetCustomerRepricingConfigRequest,
    GetCustomerRequest,
    GetEntitlementRequest,
    ImportCustomerRequest,
    ListChannelPartnerLinksRequest,
    ListChannelPartnerLinksResponse,
    ListChannelPartnerRepricingConfigsRequest,
    ListChannelPartnerRepricingConfigsResponse,
    ListCustomerRepricingConfigsRequest,
    ListCustomerRepricingConfigsResponse,
    ListCustomersRequest,
    ListCustomersResponse,
    ListEntitlementsRequest,
    ListEntitlementsResponse,
    ListOffersRequest,
    ListOffersResponse,
    ListProductsRequest,
    ListProductsResponse,
    ListPurchasableOffersRequest,
    ListPurchasableOffersResponse,
    ListPurchasableSkusRequest,
    ListPurchasableSkusResponse,
    ListSkusRequest,
    ListSkusResponse,
    ListSubscribersRequest,
    ListSubscribersResponse,
    ListTransferableOffersRequest,
    ListTransferableOffersResponse,
    ListTransferableSkusRequest,
    ListTransferableSkusResponse,
    LookupOfferRequest,
    ProvisionCloudIdentityRequest,
    PurchasableOffer,
    PurchasableSku,
    RegisterSubscriberRequest,
    RegisterSubscriberResponse,
    StartPaidServiceRequest,
    SuspendEntitlementRequest,
    TransferableOffer,
    TransferEntitlementsRequest,
    TransferEntitlementsResponse,
    TransferEntitlementsToGoogleRequest,
    UnregisterSubscriberRequest,
    UnregisterSubscriberResponse,
    UpdateChannelPartnerLinkRequest,
    UpdateChannelPartnerRepricingConfigRequest,
    UpdateCustomerRepricingConfigRequest,
    UpdateCustomerRequest,
)
from .subscriber_event import CustomerEvent, EntitlementEvent, SubscriberEvent

__all__ = (
    "ChannelPartnerLink",
    "ChannelPartnerLinkState",
    "ChannelPartnerLinkView",
    "AdminUser",
    "CloudIdentityInfo",
    "EduData",
    "Value",
    "ContactInfo",
    "Customer",
    "AssociationInfo",
    "CommitmentSettings",
    "Entitlement",
    "Parameter",
    "ProvisionedService",
    "RenewalSettings",
    "TransferableSku",
    "TransferEligibility",
    "TrialSettings",
    "Constraints",
    "CustomerConstraints",
    "Offer",
    "ParameterDefinition",
    "Period",
    "Plan",
    "Price",
    "PriceByResource",
    "PricePhase",
    "PriceTier",
    "PaymentPlan",
    "PaymentType",
    "PeriodType",
    "PromotionalOrderType",
    "ResourceType",
    "OperationMetadata",
    "MarketingInfo",
    "Media",
    "Product",
    "Sku",
    "MediaType",
    "ChannelPartnerRepricingConfig",
    "CustomerRepricingConfig",
    "PercentageAdjustment",
    "RepricingAdjustment",
    "RepricingConfig",
    "RebillingBasis",
    "ActivateEntitlementRequest",
    "CancelEntitlementRequest",
    "ChangeOfferRequest",
    "ChangeParametersRequest",
    "ChangeRenewalSettingsRequest",
    "CheckCloudIdentityAccountsExistRequest",
    "CheckCloudIdentityAccountsExistResponse",
    "CloudIdentityCustomerAccount",
    "CreateChannelPartnerLinkRequest",
    "CreateChannelPartnerRepricingConfigRequest",
    "CreateCustomerRepricingConfigRequest",
    "CreateCustomerRequest",
    "CreateEntitlementRequest",
    "DeleteChannelPartnerRepricingConfigRequest",
    "DeleteCustomerRepricingConfigRequest",
    "DeleteCustomerRequest",
    "GetChannelPartnerLinkRequest",
    "GetChannelPartnerRepricingConfigRequest",
    "GetCustomerRepricingConfigRequest",
    "GetCustomerRequest",
    "GetEntitlementRequest",
    "ImportCustomerRequest",
    "ListChannelPartnerLinksRequest",
    "ListChannelPartnerLinksResponse",
    "ListChannelPartnerRepricingConfigsRequest",
    "ListChannelPartnerRepricingConfigsResponse",
    "ListCustomerRepricingConfigsRequest",
    "ListCustomerRepricingConfigsResponse",
    "ListCustomersRequest",
    "ListCustomersResponse",
    "ListEntitlementsRequest",
    "ListEntitlementsResponse",
    "ListOffersRequest",
    "ListOffersResponse",
    "ListProductsRequest",
    "ListProductsResponse",
    "ListPurchasableOffersRequest",
    "ListPurchasableOffersResponse",
    "ListPurchasableSkusRequest",
    "ListPurchasableSkusResponse",
    "ListSkusRequest",
    "ListSkusResponse",
    "ListSubscribersRequest",
    "ListSubscribersResponse",
    "ListTransferableOffersRequest",
    "ListTransferableOffersResponse",
    "ListTransferableSkusRequest",
    "ListTransferableSkusResponse",
    "LookupOfferRequest",
    "ProvisionCloudIdentityRequest",
    "PurchasableOffer",
    "PurchasableSku",
    "RegisterSubscriberRequest",
    "RegisterSubscriberResponse",
    "StartPaidServiceRequest",
    "SuspendEntitlementRequest",
    "TransferableOffer",
    "TransferEntitlementsRequest",
    "TransferEntitlementsResponse",
    "TransferEntitlementsToGoogleRequest",
    "UnregisterSubscriberRequest",
    "UnregisterSubscriberResponse",
    "UpdateChannelPartnerLinkRequest",
    "UpdateChannelPartnerRepricingConfigRequest",
    "UpdateCustomerRepricingConfigRequest",
    "UpdateCustomerRequest",
    "CustomerEvent",
    "EntitlementEvent",
    "SubscriberEvent",
)
